"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Verify2 = void 0;
const server_client_1 = require("@vonage/server-client");
/**
 * A class for interacting with the Vonage Verify API (Version 2).
 */
class Verify2 extends server_client_1.Client {
    /**
     * The authentication type used for this client (JWT).
     */
    authType = server_client_1.AuthenticationType.JWT;
    /**
     * Creates a new verification request.
     *
     * @param {VerificationRequestParams} params - The parameters for the
     *  verification request.
     * @return {Request} A `Request` object containing the request ID.
     */
    async newRequest(params) {
        const resp = await this.sendPostRequest(`${this.config.apiHost}/v2/verify`, server_client_1.Client.transformers.snakeCaseObjectKeys(params, true));
        return {
            requestId: resp.data.request_id,
            checkUrl: resp.data.check_url,
        };
    }
    /**
     * Checks a verification code against a verification request.
     * @param {string} requestId - The ID of the verification request.
     * @param {string} code - The verification code to check.
     * @return {string} The status of the verification code check.
     */
    async checkCode(requestId, code) {
        const resp = await this.sendPostRequest(`${this.config.apiHost}/v2/verify/${requestId}`, {
            code: code,
        });
        return resp.data.status;
    }
    /**
     * Cancels a verification request.
     * @param {string} requestId - The ID of the verification request to cancel.
     * @return {boolean} `true` if the cancellation was successful.
     */
    async cancel(requestId) {
        try {
            await this.sendDeleteRequest(`${this.config.apiHost}/v2/verify/${requestId}`);
            return true;
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
        }
        catch (_) {
            return false;
        }
    }
    /**
     * Generator function to list all templates across multiple pages.
     *
     * @remarks
     * This will continue calling the API to retrieve all templates until there are no more pages left.
     * The function yields each template in camelCase format.
     *
     * @param {ListAllTemplatesParams} [params={}] - Optional filter parameters, including pagination.
     * @yields {Template} - Yields each template object in camelCase format.
     *
     * @example
     * List all templates using pagination:
     * ```ts
     * for await (const template of templateClient.listAllTemplates({ pageSize: 5 })) {
     *   console.log(template.name);
     * }
     * ```
     *
     * @example
     * List all templates without pagination:
     * ```ts
     * for await (const template of templateClient.listAllTemplates()) {
     *   console.log(template.name);
     * }
     * ```
     */
    async *listAllTemplates(params = {}) {
        let next = null;
        params.page = params?.page || 1;
        do {
            const resp = await this.getTemplatePage(params);
            yield* resp.templates || [];
            next = resp.links?.next;
            params.page++;
        } while (next);
    }
    /**
     * Retrieves a single page of templates based on the provided pagination parameters.
     *
     * @param {ListAllTemplatesParams} params - The filter parameters for pagination (e.g., page number, page size).
     * @return {Promise<ListAllTemplatesResponse>} - A promise resolving to a page of templates.
     *
     * @example
     * Get a single page of templates:
     *
     * ```ts
     * const templatePage = await templateClient.getTemplatePage({
     *   page: 1,
     *   pageSize: 10
     * });
     *
     * templatePage.templates.forEach(template => {
     *   console.log(template.name);
     * });
     * ```
     */
    async getTemplatePage(params = {}) {
        const resp = await this.sendGetRequest(`${this.config.apiHost}/v2/verify/templates`, {
            ...(params.page ? { page: params.page } : {}),
            ...(params.pageSize ? { page_size: params.pageSize } : {}),
        });
        const templates = (resp.data._embedded?.templates || []).map((template) => server_client_1.Client.transformers.camelCaseObjectKeys(template));
        return {
            pageSize: resp.data.page_size,
            page: resp.data.page,
            totalPages: resp.data.total_pages,
            totalItems: resp.data.total_items,
            templates: templates,
            links: resp.data._links,
        };
    }
    /**
     * Creates a new template with the provided details.
     *
     * @param {Template} template - The template details to be created.
     * @return {Promise<Template>} - A promise resolving to the created template in camelCase format.
     *
     * @example
     * Create a new template:
     * ```ts
     * const newTemplate = await templateClient.createTemplate({
     *   name: 'My New Template',
     * });
     * console.log(newTemplate.name);
     * ```
     */
    async createTemplate(template) {
        const resp = await this.sendPostRequest(`${this.config.apiHost}/v2/verify/templates`, {
            name: template.name,
        });
        return server_client_1.Client.transformers.camelCaseObjectKeys(resp.data);
    }
    /**
     * Retrieves a single template by its unique identifier.
     *
     * @param {string} templateId - The unique identifier of the template to retrieve.
     * @return {Promise<Template>} - A promise resolving to the retrieved template in camelCase format.
     *
     * @example
     * Get a template by ID:
     * ```ts
     * const template = await templateClient.getTemplate('22f571c1-f41a-4db2-bba7-f23a069200c1');
     * console.log(template.name);
     * ```
     */
    async getTemplate(templateId) {
        const resp = await this.sendGetRequest(`${this.config.apiHost}/v2/verify/templates/${templateId}`);
        return server_client_1.Client.transformers.camelCaseObjectKeys(resp.data);
    }
    /**
     * Deletes a template by its unique identifier.
     *
     * @param {string} templateId - The unique identifier of the template to delete.
     * @return {Promise<true>} - A promise that resolves when the template is successfully deleted.
     *
     * @example
     * Delete a template by ID:
     * ```ts
     * await templateClient.deleteTemplate('22f571c1-f41a-4db2-bba7-f23a069200c1');
     * console.log('Template deleted successfully');
     * ```
     */
    async deleteTemplate(templateId) {
        await this.sendDeleteRequest(`${this.config.apiHost}/v2/verify/templates/${templateId}`);
        return true;
    }
    /**
     * Updates an existing template with the provided details.
     *
     * @param {Template} template - The full template object with updated details. The template must include its ID.
     * @return {Promise<Template>} - A promise resolving to the updated template in camelCase format.
     *
     * @example
     * Update a template:
     * ```ts
     * const updatedTemplate = await templateClient.updateTemplate({
     *   templateId: '22f571c1-f41a-4db2-bba7-f23a069200c1',
     *   name: 'Updated Template Name',
     *   isDefault: false,
     * });
     * console.log(updatedTemplate.name);
     * ```
     */
    async updateTemplate(template) {
        if (!template.templateId) {
            throw new Error('Template ID is required for updating a template');
        }
        const resp = await this.sendPatchRequest(`${this.config.apiHost}/v2/verify/templates/${template.templateId}`, {
            name: template.name,
            is_default: template.isDefault || false,
        });
        return server_client_1.Client.transformers.camelCaseObjectKeys(resp.data);
    }
    /**
     * Retrieves a page of template fragments based on the provided pagination and filter parameters.
     *
     * @param {ListAllTemplateFragmentsQueryParams} params - The filter parameters for pagination (e.g., page number, page size, template ID).
     * @return {Promise<ListAllTemplateFragmentsResponse>} - A promise resolving to a page of template fragments.
     *
     * @example
     * Get a page of template fragments:
     * ```ts
     * const fragmentPage = await templateClient.getTemplateFragmentPage({
     *   templateId: '22f571c1-f41a-4db2-bba7-f23a069200c1',
     *   page: 1,
     *   pageSize: 10,
     * });
     * fragmentPage._embedded.template_fragments.forEach(fragment => {
     *   console.log(fragment.text);
     * });
     * ```
     */
    async getTemplateFragmentPage(params) {
        const resp = await this.sendGetRequest(`${this.config.apiHost}/v2/verify/templates/${params.templateId}/template_fragments`, {
            ...(params.page ? { page: params.page } : {}),
            ...(params.pageSize ? { page_size: params.pageSize } : {}),
        });
        const fragments = (resp.data._embedded?.template_fragments || []).map((fragment) => server_client_1.Client.transformers.camelCaseObjectKeys(fragment));
        return {
            pageSize: resp.data.page_size,
            page: resp.data.page,
            totalPages: resp.data.total_pages,
            totalItems: resp.data.total_items,
            fragments: fragments,
            links: resp.data._links,
        };
    }
    /**
     * Generator function to list all templates across multiple pages.
     *
     * @remarks
     * This will continue calling the API to retrieve all templates until there are no more pages left.
     * The function yields each template in camelCase format.
     *
     * @param {ListAllTemplateFragmentsParams} [params={}] - Optional filter parameters, including pagination.
     * @yields {TemplateFragment} - Yields each template object in camelCase format.
     *
     * @example
     * List all templates using pagination:
     * ```ts
     * for await (const template of templateClient.listAllTemplateFragments({ pageSize: 5 })) {
     *   console.log(template.name);
     * }
     * ```
     *
     * @example
     * List all templates without pagination:
     * ```ts
     * for await (const template of templateClient.listAllTemplateFragments()) {
     *   console.log(template.name);
     * }
     * ```
     */
    async *listAllTemplateFragments(params) {
        let next = null;
        params.page = params?.page || 1;
        do {
            const resp = await this.getTemplateFragmentPage(params);
            yield* resp.fragments || [];
            next = resp.links?.next;
            params.page++;
        } while (next);
    }
    /**
     * Retrieves a single template fragment by its unique identifier.
     *
     * @param {string} templateId - The unique identifier of the template.
     * @param {string} fragmentId - The unique identifier of the template fragment.
     * @return {Promise<TemplateFragmentResponse>} - A promise resolving to the retrieved template fragment in snake_case format.
     *
     * @example
     * Get a template fragment by ID:
     * ```ts
     * const fragment = await templateClient.getTemplateFragment('22f571c1-f41a-4db2-bba7-f23a069200c1', 'c70f446e-997a-4313-a081-60a02a31dc19');
     * console.log(fragment.text);
     * ```
     */
    async getTemplateFragment(templateId, fragmentId) {
        // Send a GET request to retrieve the specified template fragment by its ID
        const resp = await this.sendGetRequest(`${this.config.apiHost}/v2/verify/templates/${templateId}/template_fragments/${fragmentId}`);
        return server_client_1.Client.transformers.camelCaseObjectKeys(resp.data, true);
    }
    /**
     * Creates a new template fragment with the provided details.
     *
     * @param {string} templateId - The unique identifier of the template to which the fragment belongs.
     * @param {TemplateFragment} fragment - The details of the template fragment to be created.
     * @return {Promise<TemplateFragment>} - A promise resolving to the created template fragment in camelCase format.
     *
     * @example
     * Create a new template fragment:
     * ```ts
     * const newFragment = await templateClient.createTemplateFragment(
     *   '22f571c1-f41a-4db2-bba7-f23a069200c1',
     *   {
     *     channel: 'sms',
     *     locale: 'en-us',
     *     text: 'Your verification code is ${code}',
     *   },
     * );
     * console.log(newFragment.text);
     * ```
     */
    async createTemplateFragment(templateId, fragment) {
        const resp = await this.sendPostRequest(`${this.config.apiHost}/v2/verify/templates/${templateId}/template_fragments`, {
            channel: fragment.channel,
            locale: fragment.locale,
            text: fragment.text,
        });
        return server_client_1.Client.transformers.camelCaseObjectKeys(resp.data);
    }
    /**
     * Deletes a template fragment by its unique identifier.
     *
     * @param {string} templateId - The unique identifier of the template to delete.
     * @param {string} fragmentId - The unique identifier of the template to delete.
     * @return {Promise<true>} - A promise that resolves when the template is successfully deleted.
     *
     * @example
     * Delete a template by ID:
     * ```ts
     * await templateClient.deleteTemplateFragment(
     *   '22f571c1-f41a-4db2-bba7-f23a069200c1'
     *   'c70f446e-997a-4313-a081-60a02a31dc19',
     * );
     * console.log('Template Fragment deleted successfully');
     * ```
     */
    async deleteTemplateFragment(templateId, fragmentId) {
        await this.sendDeleteRequest(`${this.config.apiHost}/v2/verify/templates/${templateId}/template_fragments/${fragmentId}`);
        return true;
    }
    /**
     * Updates an existing template with the provided details.
     *
     * @param {String} templateId - The ID of the template this fragment belongs to.
     * @param {TemplateFragment} fragment - The full template fragment object with updated details.
     * @return {Promise<TemplateFragment>} - A promise resolving to the updated template fragment in camelCase format.
     *
     * @example
     * Update a template:
     * ```ts
     * const updatedTemplateFragment = await templateClient.updateTemplateFragment(
     *  '22f571c1-f41a-4db2-bba7-f23a069200c1',
     *   {
     *     templateId: '22f571c1-f41a-4db2-bba7-f23a069200c1',
     *     name: 'Updated Template Name',
     *     isDefault: false,
     *   }
     * );
     * console.log(updatedTemplateFragment.name);
     * ```
     */
    async updateTemplateFragment(templateId, fragment) {
        if (!fragment.templateFragmentId) {
            throw new Error('Template Fragment ID is required for updating a template fragment');
        }
        const resp = await this.sendPatchRequest(`${this.config.apiHost}/v2/verify/templates/${templateId}/template_fragments/${fragment.templateFragmentId}`, {
            text: fragment.text
        });
        return server_client_1.Client.transformers.camelCaseObjectKeys(resp.data);
    }
}
exports.Verify2 = Verify2;
//# sourceMappingURL=verify2.js.map